@@ -34,9 +34,9 @@ _snapd_get_aliases_new (GCancellable *cancellable, GAsyncReadyCallback callback,
 }
 
 GPtrArray *
-_snapd_get_aliases_get_aliases (SnapdGetAliases *request)
+_snapd_get_aliases_get_aliases (SnapdGetAliases *self)
 {
-    return request->aliases;
+    return self->aliases;
 }
 
 static SoupMessage *
@@ -48,28 +48,21 @@ generate_get_aliases_request (SnapdRequest *request)
 static gboolean
 parse_get_aliases_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetAliases *r = SNAPD_GET_ALIASES (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
-    g_autoptr(GPtrArray) aliases = NULL;
-    JsonObjectIter snap_iter;
-    const gchar *snap;
-    JsonNode *snap_node;
+    SnapdGetAliases *self = SNAPD_GET_ALIASES (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    g_autoptr(JsonObject) result = _snapd_json_get_sync_result_o (response, error);
     if (result == NULL)
         return FALSE;
 
-    aliases = g_ptr_array_new_with_free_func (g_object_unref);
+    g_autoptr(GPtrArray) aliases = g_ptr_array_new_with_free_func (g_object_unref);
+    JsonObjectIter snap_iter;
     json_object_iter_init (&snap_iter, result);
+    const gchar *snap;
+    JsonNode *snap_node;
     while (json_object_iter_next (&snap_iter, &snap, &snap_node)) {
-        JsonObjectIter alias_iter;
-        const gchar *name;
-        JsonNode *alias_node;
-
         if (json_node_get_value_type (snap_node) != JSON_TYPE_OBJECT) {
             g_set_error (error,
                          SNAPD_ERROR,
@@ -78,45 +71,20 @@ parse_get_aliases_response (SnapdRequest *request, SoupMessage *message, SnapdMa
             return FALSE;
         }
 
+        JsonObjectIter alias_iter;
         json_object_iter_init (&alias_iter, json_node_get_object (snap_node));
+        const gchar *name;
+        JsonNode *alias_node;
         while (json_object_iter_next (&alias_iter, &name, &alias_node)) {
-            JsonObject *o;
-            SnapdAliasStatus status = SNAPD_ALIAS_STATUS_UNKNOWN;
-            const gchar *status_string;
-            g_autoptr(SnapdAlias) alias = NULL;
-
-            if (json_node_get_value_type (alias_node) != JSON_TYPE_OBJECT) {
-                g_set_error (error,
-                             SNAPD_ERROR,
-                             SNAPD_ERROR_READ_FAILED,
-                             "Unexpected alias type");
+            SnapdAlias *alias = _snapd_json_parse_alias (alias_node, snap, name, error);
+            if (alias == NULL)
                 return FALSE;
-            }
 
-            o = json_node_get_object (alias_node);
-            status_string = _snapd_json_get_string (o, "status", NULL);
-            if (strcmp (status_string, "disabled") == 0)
-                status = SNAPD_ALIAS_STATUS_DISABLED;
-            else if (strcmp (status_string, "auto") == 0)
-                status = SNAPD_ALIAS_STATUS_AUTO;
-            else if (strcmp (status_string, "manual") == 0)
-                status = SNAPD_ALIAS_STATUS_MANUAL;
-            else
-                status = SNAPD_ALIAS_STATUS_UNKNOWN;
-
-            alias = g_object_new (SNAPD_TYPE_ALIAS,
-                                  "snap", snap,
-                                  "app-auto", _snapd_json_get_string (o, "auto", NULL),
-                                  "app-manual", _snapd_json_get_string (o, "manual", NULL),
-                                  "command", _snapd_json_get_string (o, "command", NULL),
-                                  "name", name,
-                                  "status", status,
-                                  NULL);
-            g_ptr_array_add (aliases, g_steal_pointer (&alias));
+            g_ptr_array_add (aliases, alias);
         }
     }
 
-    r->aliases = g_steal_pointer (&aliases);
+    self->aliases = g_steal_pointer (&aliases);
 
     return TRUE;
 }
@@ -124,9 +92,9 @@ parse_get_aliases_response (SnapdRequest *request, SoupMessage *message, SnapdMa
 static void
 snapd_get_aliases_finalize (GObject *object)
 {
-    SnapdGetAliases *request = SNAPD_GET_ALIASES (object);
+    SnapdGetAliases *self = SNAPD_GET_ALIASES (object);
 
-    g_clear_pointer (&request->aliases, g_ptr_array_unref);
+    g_clear_pointer (&self->aliases, g_ptr_array_unref);
 
     G_OBJECT_CLASS (snapd_get_aliases_parent_class)->finalize (object);
 }
@@ -143,6 +111,6 @@ snapd_get_aliases_class_init (SnapdGetAliasesClass *klass)
 }
 
 static void
-snapd_get_aliases_init (SnapdGetAliases *request)
+snapd_get_aliases_init (SnapdGetAliases *self)
 {
 }
