@@ -16,7 +16,8 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (SnapdGetApps, snapd_get_apps, SNAPD, GET_APPS, SnapdRequest)
 
-SnapdGetApps *_snapd_get_apps_new        (GCancellable        *cancellable,
+SnapdGetApps *_snapd_get_apps_new        (GStrv                snaps,
+                                          GCancellable        *cancellable,
                                           GAsyncReadyCallback  callback,
                                           gpointer             user_data);
 
