@@ -37,9 +37,7 @@ generate_get_buy_ready_request (SnapdRequest *request)
 static gboolean
 parse_get_buy_ready_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    g_autoptr(JsonObject) response = NULL;
-
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
 
@@ -56,6 +54,6 @@ snapd_get_buy_ready_class_init (SnapdGetBuyReadyClass *klass)
 }
 
 static void
-snapd_get_buy_ready_init (SnapdGetBuyReady *request)
+snapd_get_buy_ready_init (SnapdGetBuyReady *self)
 {
 }
