@@ -25,65 +25,63 @@ G_DEFINE_TYPE (SnapdGetChange, snapd_get_change, snapd_request_get_type ())
 SnapdGetChange *
 _snapd_get_change_new (const gchar *change_id, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdGetChange *request;
+    SnapdGetChange *self = SNAPD_GET_CHANGE (g_object_new (snapd_get_change_get_type (),
+                                                           "cancellable", cancellable,
+                                                           "ready-callback", callback,
+                                                           "ready-callback-data", user_data,
+                                                           NULL));
+    self->change_id = g_strdup (change_id);
 
-    request = SNAPD_GET_CHANGE (g_object_new (snapd_get_change_get_type (),
-                                              "cancellable", cancellable,
-                                              "ready-callback", callback,
-                                              "ready-callback-data", user_data,
-                                              NULL));
-    request->change_id = g_strdup (change_id);
-
-    return request;
+    return self;
 }
 
 const gchar *
-_snapd_get_change_get_change_id (SnapdGetChange *request)
+_snapd_get_change_get_change_id (SnapdGetChange *self)
 {
-    return request->change_id;
+    return self->change_id;
 }
 
 SnapdChange *
-_snapd_get_change_get_change (SnapdGetChange *request)
+_snapd_get_change_get_change (SnapdGetChange *self)
 {
-    return request->change;
+    return self->change;
 }
 
 JsonNode *
-_snapd_get_change_get_data (SnapdGetChange *request)
+_snapd_get_change_get_data (SnapdGetChange *self)
 {
-    return request->data;
+    return self->data;
 }
 
 static SoupMessage *
 generate_get_change_request (SnapdRequest *request)
 {
-    SnapdGetChange *r = SNAPD_GET_CHANGE (request);
-    g_autofree gchar *path = NULL;
+    SnapdGetChange *self = SNAPD_GET_CHANGE (request);
 
-    path = g_strdup_printf ("http://snapd/v2/changes/%s", r->change_id);
+    g_autofree gchar *path = g_strdup_printf ("http://snapd/v2/changes/%s", self->change_id);
     return soup_message_new ("GET", path);
 }
 
 static gboolean
 parse_get_change_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetChange *r = SNAPD_GET_CHANGE (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
+    SnapdGetChange *self = SNAPD_GET_CHANGE (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    /* FIXME: Needs json-glib to be fixed to use json_node_unref */
+    /*g_autoptr(JsonNode) result = NULL;*/
+    JsonNode *result = _snapd_json_get_sync_result (response, error);
     if (result == NULL)
         return FALSE;
 
-    r->change = _snapd_json_parse_change (result, error);
-    if (r->change == NULL)
+    self->change = _snapd_json_parse_change (result, error);
+    json_node_unref (result);
+    if (self->change == NULL)
         return FALSE;
 
-    if (g_strcmp0 (r->change_id, snapd_change_get_id (r->change)) != 0) {
+    if (g_strcmp0 (self->change_id, snapd_change_get_id (self->change)) != 0) {
         g_set_error (error,
                      SNAPD_ERROR,
                      SNAPD_ERROR_READ_FAILED,
@@ -91,8 +89,8 @@ parse_get_change_response (SnapdRequest *request, SoupMessage *message, SnapdMai
         return FALSE;
     }
 
-    if (json_object_has_member (result, "data"))
-        r->data = json_node_ref (json_object_get_member (result, "data"));
+    if (json_object_has_member (json_node_get_object (result), "data"))
+        self->data = json_node_ref (json_object_get_member (json_node_get_object (result), "data"));
 
     return TRUE;
 }
@@ -100,11 +98,11 @@ parse_get_change_response (SnapdRequest *request, SoupMessage *message, SnapdMai
 static void
 snapd_get_change_finalize (GObject *object)
 {
-    SnapdGetChange *request = SNAPD_GET_CHANGE (object);
+    SnapdGetChange *self = SNAPD_GET_CHANGE (object);
 
-    g_clear_pointer (&request->change_id, g_free);
-    g_clear_object (&request->change);
-    g_clear_pointer (&request->data, json_node_unref);
+    g_clear_pointer (&self->change_id, g_free);
+    g_clear_object (&self->change);
+    g_clear_pointer (&self->data, json_node_unref);
 
     G_OBJECT_CLASS (snapd_get_change_parent_class)->finalize (object);
 }
@@ -121,6 +119,6 @@ snapd_get_change_class_init (SnapdGetChangeClass *klass)
 }
 
 static void
-snapd_get_change_init (SnapdGetChange *request)
+snapd_get_change_init (SnapdGetChange *self)
 {
 }
