@@ -25,48 +25,42 @@ G_DEFINE_TYPE (SnapdGetChanges, snapd_get_changes, snapd_request_get_type ())
 SnapdGetChanges *
 _snapd_get_changes_new (const gchar *select, const gchar *snap_name, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdGetChanges *request;
+    SnapdGetChanges *self = SNAPD_GET_CHANGES (g_object_new (snapd_get_changes_get_type (),
+                                                             "cancellable", cancellable,
+                                                             "ready-callback", callback,
+                                                             "ready-callback-data", user_data,
+                                                             NULL));
+    self->select = g_strdup (select);
+    self->snap_name = g_strdup (snap_name);
 
-    request = SNAPD_GET_CHANGES (g_object_new (snapd_get_changes_get_type (),
-                                               "cancellable", cancellable,
-                                               "ready-callback", callback,
-                                               "ready-callback-data", user_data,
-                                               NULL));
-    request->select = g_strdup (select);
-    request->snap_name = g_strdup (snap_name);
-
-    return request;
+    return self;
 }
 
 GPtrArray *
-_snapd_get_changes_get_changes (SnapdGetChanges *request)
+_snapd_get_changes_get_changes (SnapdGetChanges *self)
 {
-    return request->changes;
+    return self->changes;
 }
 
 static SoupMessage *
 generate_get_changes_request (SnapdRequest *request)
 {
-    SnapdGetChanges *r = SNAPD_GET_CHANGES (request);
-    g_autoptr(GPtrArray) query_attributes = NULL;
-    g_autoptr(GString) path = NULL;
+    SnapdGetChanges *self = SNAPD_GET_CHANGES (request);
 
-    query_attributes = g_ptr_array_new_with_free_func (g_free);
-    if (r->select != NULL) {
-        g_autofree gchar *escaped = soup_uri_encode (r->select, NULL);
+    g_autoptr(GPtrArray) query_attributes = g_ptr_array_new_with_free_func (g_free);
+    if (self->select != NULL) {
+        g_autofree gchar *escaped = soup_uri_encode (self->select, NULL);
         g_ptr_array_add (query_attributes, g_strdup_printf ("select=%s", escaped));
     }
-    if (r->snap_name != NULL) {
-        g_autofree gchar *escaped = soup_uri_encode (r->snap_name, NULL);
+    if (self->snap_name != NULL) {
+        g_autofree gchar *escaped = soup_uri_encode (self->snap_name, NULL);
         g_ptr_array_add (query_attributes, g_strdup_printf ("for=%s", escaped));
     }
 
-    path = g_string_new ("http://snapd/v2/changes");
+    g_autoptr(GString) path = g_string_new ("http://snapd/v2/changes");
     if (query_attributes->len > 0) {
-        guint i;
-
         g_string_append_c (path, '?');
-        for (i = 0; i < query_attributes->len; i++) {
+        for (guint i = 0; i < query_attributes->len; i++) {
             if (i != 0)
                 g_string_append_c (path, '&');
             g_string_append (path, (gchar *) query_attributes->pdata[i]);
@@ -79,36 +73,27 @@ generate_get_changes_request (SnapdRequest *request)
 static gboolean
 parse_get_changes_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetChanges *r = SNAPD_GET_CHANGES (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonArray) result = NULL;
-    g_autoptr(GPtrArray) changes = NULL;
-    guint i;
+    SnapdGetChanges *self = SNAPD_GET_CHANGES (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_a (response, error);
+    g_autoptr(JsonArray) result = _snapd_json_get_sync_result_a (response, error);
     if (result == NULL)
         return FALSE;
 
-    changes = g_ptr_array_new_with_free_func (g_object_unref);
-    for (i = 0; i < json_array_get_length (result); i++) {
+    g_autoptr(GPtrArray) changes = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (result); i++) {
         JsonNode *node = json_array_get_element (result, i);
-        SnapdChange *change;
 
-        if (json_node_get_value_type (node) != JSON_TYPE_OBJECT) {
-            g_set_error (error, SNAPD_ERROR, SNAPD_ERROR_READ_FAILED, "Unexpected snap type");
-            return FALSE;
-        }
-
-        change = _snapd_json_parse_change (json_node_get_object (node), error);
+        SnapdChange *change = _snapd_json_parse_change (node, error);
         if (change == NULL)
             return FALSE;
+
         g_ptr_array_add (changes, change);
     }
 
-    r->changes = g_steal_pointer (&changes);
+    self->changes = g_steal_pointer (&changes);
 
     return TRUE;
 }
@@ -116,11 +101,11 @@ parse_get_changes_response (SnapdRequest *request, SoupMessage *message, SnapdMa
 static void
 snapd_get_changes_finalize (GObject *object)
 {
-    SnapdGetChanges *request = SNAPD_GET_CHANGES (object);
+    SnapdGetChanges *self = SNAPD_GET_CHANGES (object);
 
-    g_clear_pointer (&request->select, g_free);
-    g_clear_pointer (&request->snap_name, g_free);
-    g_clear_pointer (&request->changes, g_ptr_array_unref);
+    g_clear_pointer (&self->select, g_free);
+    g_clear_pointer (&self->snap_name, g_free);
+    g_clear_pointer (&self->changes, g_ptr_array_unref);
 
     G_OBJECT_CLASS (snapd_get_changes_parent_class)->finalize (object);
 }
@@ -137,6 +122,6 @@ snapd_get_changes_class_init (SnapdGetChangesClass *klass)
 }
 
 static void
-snapd_get_changes_init (SnapdGetChanges *request)
+snapd_get_changes_init (SnapdGetChanges *self)
 {
 }
