@@ -24,32 +24,29 @@ G_DEFINE_TYPE (SnapdGetIcon, snapd_get_icon, snapd_request_get_type ())
 SnapdGetIcon *
 _snapd_get_icon_new (const gchar *name, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdGetIcon *request;
+    SnapdGetIcon *self = SNAPD_GET_ICON (g_object_new (snapd_get_icon_get_type (),
+                                                       "cancellable", cancellable,
+                                                       "ready-callback", callback,
+                                                       "ready-callback-data", user_data,
+                                                       NULL));
+    self->name = g_strdup (name);
 
-    request = SNAPD_GET_ICON (g_object_new (snapd_get_icon_get_type (),
-                                            "cancellable", cancellable,
-                                            "ready-callback", callback,
-                                            "ready-callback-data", user_data,
-                                            NULL));
-    request->name = g_strdup (name);
-
-    return request;
+    return self;
 }
 
 SnapdIcon *
-_snapd_get_icon_get_icon (SnapdGetIcon *request)
+_snapd_get_icon_get_icon (SnapdGetIcon *self)
 {
-    return request->icon;
+    return self->icon;
 }
 
 static SoupMessage *
 generate_get_icon_request (SnapdRequest *request)
 {
-    SnapdGetIcon *r = SNAPD_GET_ICON (request);
-    g_autofree gchar *escaped = NULL, *path = NULL;
+    SnapdGetIcon *self = SNAPD_GET_ICON (request);
 
-    escaped = soup_uri_encode (r->name, NULL);
-    path = g_strdup_printf ("http://snapd/v2/icons/%s/icon", escaped);
+    g_autofree gchar *escaped = soup_uri_encode (self->name, NULL);
+    g_autofree gchar *path = g_strdup_printf ("http://snapd/v2/icons/%s/icon", escaped);
 
     return soup_message_new ("GET", path);
 }
@@ -57,21 +54,14 @@ generate_get_icon_request (SnapdRequest *request)
 static gboolean
 parse_get_icon_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetIcon *r = SNAPD_GET_ICON (request);
-    const gchar *content_type;
-    g_autoptr(SoupBuffer) buffer = NULL;
-    g_autoptr(GBytes) data = NULL;
-    g_autoptr(SnapdIcon) icon = NULL;
+    SnapdGetIcon *self = SNAPD_GET_ICON (request);
 
-    content_type = soup_message_headers_get_content_type (message->response_headers, NULL);
+    const gchar *content_type = soup_message_headers_get_content_type (message->response_headers, NULL);
     if (g_strcmp0 (content_type, "application/json") == 0) {
-        g_autoptr(JsonObject) response = NULL;
-        g_autoptr(JsonObject) result = NULL;
-
-        response = _snapd_json_parse_response (message, maintenance, error);
+        g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
         if (response == NULL)
             return FALSE;
-        result = _snapd_json_get_sync_result_o (response, error);
+        g_autoptr(JsonObject) result = _snapd_json_get_sync_result_o (response, error);
         if (result == NULL)
             return FALSE;
 
@@ -90,14 +80,14 @@ parse_get_icon_response (SnapdRequest *request, SoupMessage *message, SnapdMaint
         return FALSE;
     }
 
-    buffer = soup_message_body_flatten (message->response_body);
-    data = soup_buffer_get_as_bytes (buffer);
-    icon = g_object_new (SNAPD_TYPE_ICON,
-                         "mime-type", content_type,
-                         "data", data,
-                         NULL);
+    g_autoptr(SoupBuffer) buffer = soup_message_body_flatten (message->response_body);
+    g_autoptr(GBytes) data = soup_buffer_get_as_bytes (buffer);
+    g_autoptr(SnapdIcon) icon = g_object_new (SNAPD_TYPE_ICON,
+                                              "mime-type", content_type,
+                                              "data", data,
+                                              NULL);
 
-    r->icon = g_steal_pointer (&icon);
+    self->icon = g_steal_pointer (&icon);
 
     return TRUE;
 }
@@ -105,10 +95,10 @@ parse_get_icon_response (SnapdRequest *request, SoupMessage *message, SnapdMaint
 static void
 snapd_get_icon_finalize (GObject *object)
 {
-    SnapdGetIcon *request = SNAPD_GET_ICON (object);
+    SnapdGetIcon *self = SNAPD_GET_ICON (object);
 
-    g_clear_pointer (&request->name, g_free);
-    g_clear_object (&request->icon);
+    g_clear_pointer (&self->name, g_free);
+    g_clear_object (&self->icon);
 
     G_OBJECT_CLASS (snapd_get_icon_parent_class)->finalize (object);
 }
@@ -125,6 +115,6 @@ snapd_get_icon_class_init (SnapdGetIconClass *klass)
 }
 
 static void
-snapd_get_icon_init (SnapdGetIcon *request)
+snapd_get_icon_init (SnapdGetIcon *self)
 {
 }
