@@ -27,54 +27,50 @@ SnapdPostCreateUser *
 _snapd_post_create_user_new (const gchar *email,
                              GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdPostCreateUser *request;
+    SnapdPostCreateUser *self = SNAPD_POST_CREATE_USER (g_object_new (snapd_post_create_user_get_type (),
+                                                                      "cancellable", cancellable,
+                                                                      "ready-callback", callback,
+                                                                      "ready-callback-data", user_data,
+                                                                      NULL));
+    self->email = g_strdup (email);
 
-    request = SNAPD_POST_CREATE_USER (g_object_new (snapd_post_create_user_get_type (),
-                                                    "cancellable", cancellable,
-                                                    "ready-callback", callback,
-                                                    "ready-callback-data", user_data,
-                                                    NULL));
-    request->email = g_strdup (email);
-
-    return request;
+    return self;
 }
 
 void
-_snapd_post_create_user_set_sudoer (SnapdPostCreateUser *request, gboolean sudoer)
+_snapd_post_create_user_set_sudoer (SnapdPostCreateUser *self, gboolean sudoer)
 {
-    request->sudoer = sudoer;
+    self->sudoer = sudoer;
 }
 
 void
-_snapd_post_create_user_set_known (SnapdPostCreateUser *request, gboolean known)
+_snapd_post_create_user_set_known (SnapdPostCreateUser *self, gboolean known)
 {
-    request->known = known;
+    self->known = known;
 }
 
 SnapdUserInformation *
-_snapd_post_create_user_get_user_information (SnapdPostCreateUser *request)
+_snapd_post_create_user_get_user_information (SnapdPostCreateUser *self)
 {
-    return request->user_information;
+    return self->user_information;
 }
 
 static SoupMessage *
 generate_post_create_user_request (SnapdRequest *request)
 {
-    SnapdPostCreateUser *r = SNAPD_POST_CREATE_USER (request);
-    SoupMessage *message;
-    g_autoptr(JsonBuilder) builder = NULL;
+    SnapdPostCreateUser *self = SNAPD_POST_CREATE_USER (request);
 
-    message = soup_message_new ("POST", "http://snapd/v2/create-user");
+    SoupMessage *message = soup_message_new ("POST", "http://snapd/v2/create-user");
 
-    builder = json_builder_new ();
+    g_autoptr(JsonBuilder) builder = json_builder_new ();
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "email");
-    json_builder_add_string_value (builder, r->email);
-    if (r->sudoer) {
+    json_builder_add_string_value (builder, self->email);
+    if (self->sudoer) {
         json_builder_set_member_name (builder, "sudoer");
         json_builder_add_boolean_value (builder, TRUE);
     }
-    if (r->known) {
+    if (self->known) {
         json_builder_set_member_name (builder, "known");
         json_builder_add_boolean_value (builder, TRUE);
     }
@@ -87,23 +83,23 @@ generate_post_create_user_request (SnapdRequest *request)
 static gboolean
 parse_post_create_user_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdPostCreateUser *r = SNAPD_POST_CREATE_USER (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
-    g_autoptr(SnapdUserInformation) user_information = NULL;
+    SnapdPostCreateUser *self = SNAPD_POST_CREATE_USER (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    /* FIXME: Needs json-glib to be fixed to use json_node_unref */
+    /*g_autoptr(JsonNode) result = NULL;*/
+    JsonNode *result = _snapd_json_get_sync_result (response, error);
     if (result == NULL)
         return FALSE;
 
-    user_information = _snapd_json_parse_user_information (result, error);
+    g_autoptr(SnapdUserInformation) user_information = _snapd_json_parse_user_information (result, error);
+    json_node_unref (result);
     if (user_information == NULL)
         return FALSE;
 
-    r->user_information = g_steal_pointer (&user_information);
+    self->user_information = g_steal_pointer (&user_information);
 
     return TRUE;
 }
@@ -111,10 +107,10 @@ parse_post_create_user_response (SnapdRequest *request, SoupMessage *message, Sn
 static void
 snapd_post_create_user_finalize (GObject *object)
 {
-    SnapdPostCreateUser *request = SNAPD_POST_CREATE_USER (object);
+    SnapdPostCreateUser *self = SNAPD_POST_CREATE_USER (object);
 
-    g_clear_pointer (&request->email, g_free);
-    g_clear_object (&request->user_information);
+    g_clear_pointer (&self->email, g_free);
+    g_clear_object (&self->user_information);
 
     G_OBJECT_CLASS (snapd_post_create_user_parent_class)->finalize (object);
 }
@@ -131,6 +127,6 @@ snapd_post_create_user_class_init (SnapdPostCreateUserClass *klass)
 }
 
 static void
-snapd_post_create_user_init (SnapdPostCreateUser *request)
+snapd_post_create_user_init (SnapdPostCreateUser *self)
 {
 }
