@@ -27,47 +27,43 @@ SnapdPostLogin *
 _snapd_post_login_new (const gchar *email, const gchar *password, const gchar *otp,
                        GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdPostLogin *request;
+    SnapdPostLogin *self = SNAPD_POST_LOGIN (g_object_new (snapd_post_login_get_type (),
+                                                           "cancellable", cancellable,
+                                                           "ready-callback", callback,
+                                                           "ready-callback-data", user_data,
+                                                           NULL));
+    self->email = g_strdup (email);
+    self->password = g_strdup (password);
+    self->otp = g_strdup (otp);
 
-    request = SNAPD_POST_LOGIN (g_object_new (snapd_post_login_get_type (),
-                                              "cancellable", cancellable,
-                                              "ready-callback", callback,
-                                              "ready-callback-data", user_data,
-                                              NULL));
-    request->email = g_strdup (email);
-    request->password = g_strdup (password);
-    request->otp = g_strdup (otp);
-
-    return request;
+    return self;
 }
 
 SnapdUserInformation *
-_snapd_post_login_get_user_information (SnapdPostLogin *request)
+_snapd_post_login_get_user_information (SnapdPostLogin *self)
 {
-    return request->user_information;
+    return self->user_information;
 }
 
 static SoupMessage *
 generate_post_login_request (SnapdRequest *request)
 {
-    SnapdPostLogin *r = SNAPD_POST_LOGIN (request);
-    SoupMessage *message;
-    g_autoptr(JsonBuilder) builder = NULL;
+    SnapdPostLogin *self = SNAPD_POST_LOGIN (request);
 
-    message = soup_message_new ("POST", "http://snapd/v2/login");
+    SoupMessage *message = soup_message_new ("POST", "http://snapd/v2/login");
 
-    builder = json_builder_new ();
+    g_autoptr(JsonBuilder) builder = json_builder_new ();
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "email");
-    json_builder_add_string_value (builder, r->email);
+    json_builder_add_string_value (builder, self->email);
     /* Send legacy username field for snapd < 2.16 */
     json_builder_set_member_name (builder, "username");
-    json_builder_add_string_value (builder, r->email);
+    json_builder_add_string_value (builder, self->email);
     json_builder_set_member_name (builder, "password");
-    json_builder_add_string_value (builder, r->password);
-    if (r->otp != NULL) {
+    json_builder_add_string_value (builder, self->password);
+    if (self->otp != NULL) {
         json_builder_set_member_name (builder, "otp");
-        json_builder_add_string_value (builder, r->otp);
+        json_builder_add_string_value (builder, self->otp);
     }
     json_builder_end_object (builder);
     _snapd_json_set_body (message, builder);
@@ -78,19 +74,20 @@ generate_post_login_request (SnapdRequest *request)
 static gboolean
 parse_post_login_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdPostLogin *r = SNAPD_POST_LOGIN (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
+    SnapdPostLogin *self = SNAPD_POST_LOGIN (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    /* FIXME: Needs json-glib to be fixed to use json_node_unref */
+    /*g_autoptr(JsonNode) result = NULL;*/
+    JsonNode *result = _snapd_json_get_sync_result (response, error);
     if (result == NULL)
         return FALSE;
 
-    r->user_information = _snapd_json_parse_user_information (result, error);
-    if (r->user_information == NULL)
+    self->user_information = _snapd_json_parse_user_information (result, error);
+    json_node_unref (result);
+    if (self->user_information == NULL)
         return FALSE;
 
     return TRUE;
@@ -99,12 +96,12 @@ parse_post_login_response (SnapdRequest *request, SoupMessage *message, SnapdMai
 static void
 snapd_post_login_finalize (GObject *object)
 {
-    SnapdPostLogin *request = SNAPD_POST_LOGIN (object);
+    SnapdPostLogin *self = SNAPD_POST_LOGIN (object);
 
-    g_clear_pointer (&request->email, g_free);
-    g_clear_pointer (&request->password, g_free);
-    g_clear_pointer (&request->otp, g_free);
-    g_clear_object (&request->user_information);
+    g_clear_pointer (&self->email, g_free);
+    g_clear_pointer (&self->password, g_free);
+    g_clear_pointer (&self->otp, g_free);
+    g_clear_object (&self->user_information);
 
     G_OBJECT_CLASS (snapd_post_login_parent_class)->finalize (object);
 }
@@ -121,6 +118,6 @@ snapd_post_login_class_init (SnapdPostLoginClass *klass)
 }
 
 static void
-snapd_post_login_init (SnapdPostLogin *request)
+snapd_post_login_init (SnapdPostLogin *self)
 {
 }
