@@ -25,49 +25,44 @@ G_DEFINE_TYPE (SnapdPostSnapctl, snapd_post_snapctl, snapd_request_get_type ())
 SnapdPostSnapctl *
 _snapd_post_snapctl_new (const gchar *context_id, GStrv args, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdPostSnapctl *request;
+    SnapdPostSnapctl *self = SNAPD_POST_SNAPCTL (g_object_new (snapd_post_snapctl_get_type (),
+                                                               "cancellable", cancellable,
+                                                               "ready-callback", callback,
+                                                               "ready-callback-data", user_data,
+                                                               NULL));
+    self->context_id = g_strdup (context_id);
+    self->args = g_strdupv (args);
 
-    request = SNAPD_POST_SNAPCTL (g_object_new (snapd_post_snapctl_get_type (),
-                                                "cancellable", cancellable,
-                                                "ready-callback", callback,
-                                                "ready-callback-data", user_data,
-                                                NULL));
-    request->context_id = g_strdup (context_id);
-    request->args = g_strdupv (args);
-
-    return request;
+    return self;
 }
 
 const gchar *
-_snapd_post_snapctl_get_stdout_output (SnapdPostSnapctl *request)
+_snapd_post_snapctl_get_stdout_output (SnapdPostSnapctl *self)
 {
-    return request->stdout_output;
+    return self->stdout_output;
 }
 
 const gchar *
-_snapd_post_snapctl_get_stderr_output (SnapdPostSnapctl *request)
+_snapd_post_snapctl_get_stderr_output (SnapdPostSnapctl *self)
 {
-    return request->stderr_output;
+    return self->stderr_output;
 }
 
 static SoupMessage *
 generate_post_snapctl_request (SnapdRequest *request)
 {
-    SnapdPostSnapctl *r = SNAPD_POST_SNAPCTL (request);
-    SoupMessage *message;
-    g_autoptr(JsonBuilder) builder = NULL;
-    int i;
+    SnapdPostSnapctl *self = SNAPD_POST_SNAPCTL (request);
 
-    message = soup_message_new ("POST", "http://snapd/v2/snapctl");
+    SoupMessage *message = soup_message_new ("POST", "http://snapd/v2/snapctl");
 
-    builder = json_builder_new ();
+    g_autoptr(JsonBuilder) builder = json_builder_new ();
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "context-id");
-    json_builder_add_string_value (builder, r->context_id);
+    json_builder_add_string_value (builder, self->context_id);
     json_builder_set_member_name (builder, "args");
     json_builder_begin_array (builder);
-    for (i = 0; r->args[i] != NULL; i++)
-        json_builder_add_string_value (builder, r->args[i]);
+    for (int i = 0; self->args[i] != NULL; i++)
+        json_builder_add_string_value (builder, self->args[i]);
     json_builder_end_array (builder);
     json_builder_end_object (builder);
     _snapd_json_set_body (message, builder);
@@ -78,19 +73,17 @@ generate_post_snapctl_request (SnapdRequest *request)
 static gboolean
 parse_post_snapctl_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdPostSnapctl *r = SNAPD_POST_SNAPCTL (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
+    SnapdPostSnapctl *self = SNAPD_POST_SNAPCTL (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    g_autoptr(JsonObject) result = _snapd_json_get_sync_result_o (response, error);
     if (result == NULL)
         return FALSE;
 
-    r->stdout_output = g_strdup (_snapd_json_get_string (result, "stdout", NULL));
-    r->stderr_output = g_strdup (_snapd_json_get_string (result, "stderr", NULL));
+    self->stdout_output = g_strdup (_snapd_json_get_string (result, "stdout", NULL));
+    self->stderr_output = g_strdup (_snapd_json_get_string (result, "stderr", NULL));
 
     return TRUE;
 }
@@ -98,12 +91,12 @@ parse_post_snapctl_response (SnapdRequest *request, SoupMessage *message, SnapdM
 static void
 snapd_post_snapctl_finalize (GObject *object)
 {
-    SnapdPostSnapctl *request = SNAPD_POST_SNAPCTL (object);
+    SnapdPostSnapctl *self = SNAPD_POST_SNAPCTL (object);
 
-    g_clear_pointer (&request->context_id, g_free);
-    g_clear_pointer (&request->args, g_strfreev);
-    g_clear_pointer (&request->stdout_output, g_free);
-    g_clear_pointer (&request->stderr_output, g_free);
+    g_clear_pointer (&self->context_id, g_free);
+    g_clear_pointer (&self->args, g_strfreev);
+    g_clear_pointer (&self->stdout_output, g_free);
+    g_clear_pointer (&self->stderr_output, g_free);
 
     G_OBJECT_CLASS (snapd_post_snapctl_parent_class)->finalize (object);
 }
@@ -120,6 +113,6 @@ snapd_post_snapctl_class_init (SnapdPostSnapctlClass *klass)
 }
 
 static void
-snapd_post_snapctl_init (SnapdPostSnapctl *request)
+snapd_post_snapctl_init (SnapdPostSnapctl *self)
 {
 }
