@@ -295,6 +295,19 @@ SnapdUserInformation   *snapd_client_login2_finish                 (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+gboolean                snapd_client_logout_sync                   (SnapdClient          *client,
+                                                                    gint64                id,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_logout_async                  (SnapdClient          *client,
+                                                                    gint64                id,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_logout_finish                 (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 void                    snapd_client_set_auth_data                 (SnapdClient          *client,
                                                                     SnapdAuthData        *auth_data);
 SnapdAuthData          *snapd_client_get_auth_data                 (SnapdClient          *client);
@@ -1094,6 +1107,23 @@ gboolean                snapd_client_run_snapctl_finish            (SnapdClient
                                                                     gchar               **stderr_output,
                                                                     GError              **error);
 
+GBytes                 *snapd_client_download_sync                 (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    const gchar          *channel,
+                                                                    const gchar          *revision,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_download_async                (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    const gchar          *channel,
+                                                                    const gchar          *revision,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GBytes                 *snapd_client_download_finish               (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 G_END_DECLS
 
 #endif /* __SNAPD_CLIENT_H__ */
