@@ -41,6 +41,8 @@ typedef enum
 
 const gchar *snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_information);
 
+const gchar *snapd_system_information_get_build_id           (SnapdSystemInformation *system_information);
+
 SnapdSystemConfinement snapd_system_information_get_confinement (SnapdSystemInformation *system_information);
 
 const gchar *snapd_system_information_get_kernel_version     (SnapdSystemInformation *system_information);
@@ -55,6 +57,18 @@ const gchar *snapd_system_information_get_os_id              (SnapdSystemInforma
 
 const gchar *snapd_system_information_get_os_version         (SnapdSystemInformation *system_information);
 
+GDateTime   *snapd_system_information_get_refresh_hold       (SnapdSystemInformation *system_information);
+
+GDateTime   *snapd_system_information_get_refresh_last       (SnapdSystemInformation *system_information);
+
+GDateTime   *snapd_system_information_get_refresh_next       (SnapdSystemInformation *system_information);
+
+const gchar *snapd_system_information_get_refresh_schedule   (SnapdSystemInformation *system_information);
+
+const gchar *snapd_system_information_get_refresh_timer      (SnapdSystemInformation *system_information);
+
+GHashTable  *snapd_system_information_get_sandbox_features   (SnapdSystemInformation *system_information);
+
 const gchar *snapd_system_information_get_series             (SnapdSystemInformation *system_information);
 
 const gchar *snapd_system_information_get_store              (SnapdSystemInformation *system_information);
