@@ -64,6 +64,23 @@ private:
     Q_DECLARE_PRIVATE(QSnapdLoginRequest)
 };
 
+class QSnapdLogoutRequestPrivate;
+class Q_DECL_EXPORT QSnapdLogoutRequest : public QSnapdRequest
+{
+    Q_OBJECT
+
+public:
+    explicit QSnapdLogoutRequest (void *snapd_client, qint64 id, QObject *parent = 0);
+    ~QSnapdLogoutRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    void handleResult (void *, void *);
+
+private:
+    QSnapdLogoutRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdLogoutRequest)
+};
+
 class QSnapdGetChangesRequestPrivate;
 class Q_DECL_EXPORT QSnapdGetChangesRequest : public QSnapdRequest
 {
@@ -861,6 +878,24 @@ private:
     Q_DECLARE_PRIVATE(QSnapdRunSnapCtlRequest)
 };
 
+class QSnapdDownloadRequestPrivate;
+class Q_DECL_EXPORT QSnapdDownloadRequest : public QSnapdRequest
+{
+    Q_OBJECT
+
+public:
+    explicit QSnapdDownloadRequest (const QString& name, const QString& channel, const QString& revision, void *snapd_client, QObject *parent = 0);
+    ~QSnapdDownloadRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE QByteArray data () const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdDownloadRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdDownloadRequest)
+};
+
 Q_INVOKABLE Q_DECL_DEPRECATED QSnapdLoginRequest *login (const QString& email, const QString& password);
 Q_INVOKABLE Q_DECL_DEPRECATED QSnapdLoginRequest *login (const QString& email, const QString& password, const QString& otp);
 
@@ -940,6 +975,7 @@ public:
     Q_INVOKABLE Q_DECL_DEPRECATED QSnapdConnectRequest *connect ();
     Q_INVOKABLE QSnapdLoginRequest *login (const QString& email, const QString& password);
     Q_INVOKABLE QSnapdLoginRequest *login (const QString& email, const QString& password, const QString& otp);
+    Q_INVOKABLE QSnapdLogoutRequest *logout (qint64 id);
     Q_INVOKABLE void setSocketPath (const QString &socketPath);
     Q_INVOKABLE QString socketPath () const;
     Q_INVOKABLE void setUserAgent (const QString &userAgent);
@@ -1026,6 +1062,8 @@ public:
     Q_INVOKABLE Q_DECL_DEPRECATED QSnapdDisableAliasesRequest *disableAliases (const QString snap, const QStringList &aliases);
     Q_INVOKABLE Q_DECL_DEPRECATED QSnapdResetAliasesRequest *resetAliases (const QString snap, const QStringList &aliases);
     Q_INVOKABLE QSnapdRunSnapCtlRequest *runSnapCtl (const QString contextId, const QStringList &args);
+    Q_INVOKABLE QSnapdDownloadRequest *download (const QString &name);
+    Q_INVOKABLE QSnapdDownloadRequest *download (const QString &name, const QString &channel, const QString &revision);
 
 private:
     QSnapdClientPrivate *d_ptr;
