@@ -41,6 +41,14 @@ public:
     SnapdAuthData *auth_data = NULL;
 };
 
+class QSnapdLogoutRequestPrivate
+{
+public:
+    QSnapdLogoutRequestPrivate (qint64 id) :
+        id (id) {}
+    qint64 id;
+};
+
 class QSnapdGetChangesRequestPrivate
 {
 public:
@@ -569,4 +577,20 @@ public:
     gchar *stderr_output = NULL;
 };
 
+class QSnapdDownloadRequestPrivate
+{
+public:
+    QSnapdDownloadRequestPrivate (const QString &name, const QString& channel, const QString& revision) :
+        name (name), channel (channel), revision (revision) {}
+    ~QSnapdDownloadRequestPrivate ()
+    {
+        if (data != NULL)
+            g_bytes_unref (data);
+    }
+    QString name;
+    QString channel;
+    QString revision;
+    GBytes *data = NULL;
+};
+
 #endif
